****Beartype** is an [open-source](https://github.com/beartype/beartype/blob/main/LICENSE) [pure-Python](https://beartype.readthedocs.io/en/latest/faq/#faq-pure) [PEP-compliant](https://beartype.readthedocs.io/en/latest/pep/#pep-pep) [near-real-time](https://beartype.readthedocs.io/en/latest/faq/#faq-realtime) [hybrid runtime-static](https://beartype.readthedocs.io/en/latest/faq/#faq-hybrid) [third-generation](https://beartype.readthedocs.io/en/latest/faq/#faq-third) [type-checker](https://beartype.readthedocs.io/en/latest/eli5/#eli5-eli5) emphasizing efficiency, usability, unsubstantiated jargon we just made up, and thrilling puns.*

*Beartype enforces [type hints](https://beartype.readthedocs.io/en/latest/eli5/#eli5-typing) across your entire app in [two lines of runtime code with no runtime overhead](https://beartype.readthedocs.io/en/latest/api_claw/#api-claw-api-claw). If seeing is believing, prepare to do both those things.*

"Third generation":
- first generation: only static type checking
- second generation: only dynamic type checking
- third generation: both
